# Trapani test


## Finite/infinite momenta

For a Landau PDF:
\begin{align*}
  E_L[x] &\longrightarrow + \infty  \\
  V_L[x] &\longrightarrow + \infty
\end{align*}

. . .

For a Moyal PDF:
\begin{align*}
  E_M[x] &= \mu + \sigma [ \gamma + \ln(2) ]  \\
  V_M[x] &= \frac{\pi^2 \sigma^2}{2}
\end{align*}


## Finite/infinite momenta

- Check whether a momentum is finite or infinite
\begin{align*}
  \text{infinite} &\thus Landau \\
  \text{finite}   &\thus Moyal
\end{align*}

. . .


# Trapani test


## Trapani test

::: incremental

  - Random variable $\left\{ x_i \right\}$ sampled from a distribution $f$
  - Sample moments according to $f$ moments
  - $H_0$: $\mu_k \longrightarrow + \infty$
  - Statistic with chi-squared distribution

:::


## Trapani test

- Start with $\left\{ x_i \right\}^N$ and compute $\mu_k$ as:
  $$
    \mu_k = \frac{1}{N} \sum_{i = 1}^N |x_i|^k
  $$

. . .

- Generate $r$ points $\left\{ \xi_j\right\}^r$ according to $G(0, 1)$ and define
  $\left\{ a_j \right\}^r$ as:
  $$
    a_j = \sqrt{e^{\mu_k}} \cdot \xi_j
    \thus G'\left( 0, \sqrt{e^{\mu_k}} \right)
  $$

. . .

The greater $\mu^k$, the 'larger' $G'$

- if $\mu_k \longrightarrow + \infty \thus a_j$ distributed uniformly


## Trapani test

- Define the sequence: $\left\{ \zeta_j (u) \right\}^r$ as:
  $$
    \zeta_j (u) = \theta( u -  a_j) \with \theta - \text{Heaviside}
  $$

. . .

\begin{center}
\begin{tikzpicture}
  \definecolor{cyclamen}{RGB}{146,24,43}
  % line
  \draw [line width=3, ->, cyclamen] (0,0) -- (10,0);
  \node [right] at (10,0) {$u$};
  % tic
  \draw [thick] (5,-0.3) -- (5,0.3);
  \node [above] at (5,0.3) {$u_0$};
  % aj tics
  \draw [thick, cyclamen]          (1,-0.2) -- (1,0.2);
  \node [below right, cyclamen] at (1,-0.2) {$a_{j+2}$};
  \draw [thick, cyclamen]          (2,-0.2) -- (2,0.2);
  \node [below right, cyclamen] at (2,-0.2) {$a_j$};
  \draw [thick, cyclamen]          (5.2,-0.2) -- (5.2,0.2);
  \node [below right, cyclamen] at (5.2,-0.2) {$a_{j+2}$};
  \draw [thick, cyclamen]          (6,-0.2) -- (6,0.2);
  \node [below right, cyclamen] at (6,-0.2) {$a_{j+3}$};
  \draw [thick, cyclamen]          (8.5,-0.2) -- (8.5,0.2);
  \node [below right, cyclamen] at (8.5,-0.2) {$a_{j+4}$};
  % notes
  \node [below] at (1,-1)   {0};
  \node [below] at (2,-1)   {0};
  \node [below] at (5.2,-1) {1};
  \node [below] at (6,-1)   {1};
  \node [below] at (8.5,-1) {1};
  \draw [thick, ->] (1,-0.5)   -- (1,-1);
  \draw [thick, ->] (2,-0.5)   -- (2,-1);
  \draw [thick, ->] (5.2,-0.5) -- (5.2,-1);
  \draw [thick, ->] (6,-0.5)   -- (6,-1);
  \draw [thick, ->] (8.5,-0.5) -- (8.5,-1);
\end{tikzpicture}
\end{center}

. . .

If $a_j$ uniformly distributed and $N \rightarrow + \infty$:

- $\zeta_j (u)$ Bernoulli PDF with $P(\zeta_j (u) = 1) = \frac{1}{2}$


## Trapani test

- Define the function $\vartheta (u)$ as:
$$
  \vartheta (u) = \frac{2}{\sqrt{r}}
                  \left[ \sum_{j} \zeta_j (u) - \frac{r}{2} \right]
$$

. . .

If $a_j$ uniformly distributed and $N \rightarrow + \infty$, for the CLT:
$$
  \sum_j \zeta_j (u) \quad \text{follows} \quad
    G \left( \frac{r}{2}, \frac{r}{4} \right)
  \thus \vartheta (u) \quad \text{follows} \quad
    G \left( 0, 1 \right)
$$

. . .

- Test statistic:
$$
  \chi^2 = \int_{\underbar{u}}^{\bar{u}} du \vartheta^2 (u)
$$


## Trapani test

According to L. Trapani (10.1016/j.jeconom.2015.08.006):

- $r = o(N)$
- $\underbar{u} = 1 \quad \wedge \quad \bar{u} = 1$

. . .

$\mu_k$ must be scale invariant for $k > 1$:

$$
  \tilde{\mu_k} = \frac{\mu_k}{ \left( \mu_{\phi} \right)^{k/\phi} }
  \with \phi \in (0, k)
$$


# Samples results


## Samples results

$N = 50000$ sampled points

. . .

Landau sample:

:::: {.columns}
:::  {.column width=50%}
  - $D = 0.004$
  - $p = 0.379$
:::

:::  {.column width=50%}
  $$
  \thus \text{Compatible!}
  $$
:::
::::

\vspace{10pt}

. . .

Moyal sample:

:::: {.columns}
:::  {.column width=50%}
  - $D = 0.153$
  - $p = 0.000$
:::

:::  {.column width=50%}
  $$
  \thus \text{Not compatible!}
  $$
:::
::::
